#! /usr/bin/env bash
#
# Copyright (c) 2013 Toni de la Fuente.
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the Apache License as published by the Apache Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. 
#
# Most recent information about this tool is available in:
# http://blyx.com/alfresco-bart
#
# Latest code available at:
# http://blyx.com/alfresco-bart
#
#########################################################################################
# alfresco-bart: ALFRESCO BACKUP AND RECOVERY TOOL 
# Version 0.1       
#########################################################################################
# ACTION REQUIRED:
# CONFIGURE alfresco-bart in the alfresco-bart.properties file and ALFBRT_PATH
# in this file.
# Copy all files in you ALFRESCO_INSTALLATION_PATH/scripts.
# RUN ./alfresco-bart.sh [backup|recovery|verify|collection|list] 
#########################################################################################
#
# Run backup daily at 5AM
# 0 5 * * * root /path/to/alfresco-bart.sh backup 
#
#########################################################################################

# Load properties
ALFBRT_PATH=/opt/alfresco/scripts

if [ -f ${ALFBRT_PATH}/alfresco-bart.properties ]; then
	. ${ALFBRT_PATH}/alfresco-bart.properties 
else
	echo alfresco-bart.properties file not found, edit $0 and modify ALFBRT_PATH
fi

# Do not let this script run more than once
PROC=`ps axu | grep -v "grep" | grep --count "duplicity"`
if [ $PROC -gt 0 ]; then 
	echo "alfresco-bart.sh or duplicity is already running."
	exit 1
fi

# Command usage menu
usage(){
echo "USAGE:
    `basename $0` [mode]

Modes:
    backup		runs an incremental backup or a full if first time
    restore		runs the restore wizard
    verify [set]	verifies the backup
    collection [set]	shows all the backup sets in the archive
    list [set]		lists the files currently backed up in the archive

Sets:
    index	use index backup set (group) for selected mode
    db		use data base backup set (group) for selected mode
    cs		use content store backup set (group) for selected mode
    files	use rest of files backup set (group) for selected mode
    all		use all backup sets"
}

# Checks if encryption is required if not it adds appropiate flag
if [ $ENCRYPTION_ENABLED = "true" ]; then
	export PASSPHRASE
else
	NOENCFLAG="--no-encryption"
fi

export AWS_ACCESS_KEY_ID
export AWS_SECRET_ACCESS_KEY

# Checks backup type, target selected
case $BACKUPTYPE in
	"s3" ) 
		DEST=${S3FILESYSLOCATION}
		PARAMS="${GLOBAL_DUPLICITY_PARMS} ${S3OPTIONS} ${NOENCFLAG}"
		;;
	"ftp" ) 
		if [ ${FTPS_ENABLE} == 'false' ]; then
   			DEST=ftp://${FTP_USER}:${FTP_PASSWORD}@${FTP_SERVER}:${FTP_PORT}/${FTP_FOLDER}
   			PARAMS="${GLOBAL_DUPLICITY_PARMS} ${NOENCFLAG}"
		else
   			DEST=ftps://${FTP_USER}:${FTP_PASSWORD}@${FTP_SERVER}:${FTP_PORT}/${FTP_FOLDER}
   			PARAMS="${GLOBAL_DUPLICITY_PARMS} ${NOENCFLAG}"
		fi
		;;	
	"scp" )
		DEST=scp://${SCP_USER}@${SCP_SERVER}/${SCP_FOLDER}
		PARAMS="${GLOBAL_DUPLICITY_PARMS} ${NOENCFLAG}"
		;;
	"local" )
		# command sintax is "file:///" but last / is coming from ${LOCAL_BACKUP_FOLDER} variable
		DEST=file://${LOCAL_BACKUP_FOLDER}
		PARAMS="${GLOBAL_DUPLICITY_PARMS} ${NOENCFLAG}"
		;;
	* ) echo "$LOG_DATE_LOG - [ERROR] Unknown BACKUP type <$BACKUPTYPE>, review your alfresco-backup.properties" >> $ALFBRT_LOG_FILE;; 
esac
	
# Checks if logs directory exist 
if [ ! -d $ALFBRT_LOG_DIR ]; then
	echo Script logs directory not found, add a valid directory in 'ALFBRT_LOG_DIR'. Bye.
	exit 1
fi

function indexBackup {
	echo "$LOG_DATE_LOG - $BART_LOG_TAG Backing up the Alfresco indexes to $BACKUPTYPE" >> $ALFBRT_LOG_FILE
  	echo "$LOG_DATE_LOG - $BART_LOG_TAG Starting backup - Alfresco $INDEXTYPE indexes" >> $ALFBRT_LOG_FILE
	echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN $PARAMS $INDEXES_BACKUP_DIR $DEST/$INDEXTYPE" >> $ALFBRT_LOG_FILE
  	# Command for diplicity backup
  	$DUPLICITYBIN $PARAMS $INDEXES_BACKUP_DIR $DEST/$INDEXTYPE >> $ALFBRT_LOG_FILE
	echo "$LOG_DATE_LOG - $BART_LOG_TAG Indexes backup finished" >> $ALFBRT_LOG_FILE
}

function dbBackup {
	echo "$LOG_DATE_LOG - $BART_LOG_TAG Backing up the Alfresco db to $BACKUPTYPE" >> $ALFBRT_LOG_FILE
	echo "$LOG_DATE_LOG - $BART_LOG_TAG Starting backup - Alfresco $DBTYPE db" >> $ALFBRT_LOG_FILE
	
	if [ ! -d $ALFBRT_LOG_DIR ]; then
		echo Script logs directory not found, add a valid directory in 'ALFBRT_LOG_DIR'. Bye.
		exit 1
	fi
	
	if [ ! -d $LOCAL_BACKUP_DB_DIR ]; then
		mkdir $LOCAL_BACKUP_DB_DIR
	fi
	
	case $DBTYPE in 
		"mysql" ) 
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Backing up the Alfresco DB to $BACKUPTYPE" >> $ALFBRT_LOG_FILE
  			echo "$LOG_DATE_LOG - $BART_LOG_TAG Starting backup - Alfresco $DBTYPE DB" >> $ALFBRT_LOG_FILE
			# Mysql dump
			# TODO: Add logging for dump command
			$MYSQL_BINDIR/$MYSQLDUMP_BIN -u $DBUSER -h $DBHOST -p$DBPASS $DBNAME | $GZIP -9 > $LOCAL_BACKUP_DB_DIR/$DBNAME.dump
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN $PARAMS $LOCAL_BACKUP_DB_DIR $DEST/$DBTYPE" >> $ALFBRT_LOG_FILE
  			$DUPLICITYBIN $PARAMS $LOCAL_BACKUP_DB_DIR $DEST/$DBTYPE >> $ALFBRT_LOG_FILE
			echo "$LOG_DATE_LOG - $BART_LOG_TAG DB backup finished" >> $ALFBRT_LOG_FILE
		;; 
		"postgresql" ) 		
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Backing up the Alfresco DB to $BACKUPTYPE" >> $ALFBRT_LOG_FILE
  			echo "$LOG_DATE_LOG - $BART_LOG_TAG Starting backup - Alfresco $DBTYPE DB" >> $ALFBRT_LOG_FILE
			# PG dump in plain text format and compressed 
			# TODO: Add logging for dump command
			$PGSQL_BINDIR/$PGSQLDUMP_BIN --host=$DBHOST --username=$DBUSER --format=p --compress=9 --file=$LOCAL_BACKUP_DB_DIR/$DBNAME.dump $DBNAME -w
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN $PARAMS $LOCAL_BACKUP_DB_DIR $DEST/$DBTYPE" >> $ALFBRT_LOG_FILE
  			$DUPLICITYBIN $PARAMS $LOCAL_BACKUP_DB_DIR $DEST/$DBTYPE >> $ALFBRT_LOG_FILE
			echo "$LOG_DATE_LOG - $BART_LOG_TAG DB backup finished" >> $ALFBRT_LOG_FILE
		;; 
		
		"oracle" ) 
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Backing up the Alfresco DB to $BACKUPTYPE" >> $ALFBRT_LOG_FILE
  			echo "$LOG_DATE_LOG - $BART_LOG_TAG Starting backup - Alfresco $DBTYPE DB" >> $ALFBRT_LOG_FILE
			# Oracle export 
			# TODO: Add logging for dump command 
			# TODO: Change full options
			$ORACLE_BINDIR/$ORASQLDUMP_BIN $DBUSER/$DBPASS@$DBHOST/$DBNAME full=y file=$LOCAL_BACKUP_DB_DIR/$DBNAME.dump log=$ALFBRT_LOG_FILE
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN $PARAMS $LOCAL_BACKUP_DB_DIR $DEST/$DBTYPE" >> $ALFBRT_LOG_FILE
  			$DUPLICITYBIN $PARAMS $LOCAL_BACKUP_DB_DIR $DEST/$DBTYPE >> $ALFBRT_LOG_FILE
			echo "$LOG_DATE_LOG - $BART_LOG_TAG DB backup finished" >> $ALFBRT_LOG_FILE
		;;
		
		* ) 
		echo "$LOG_DATE_LOG - [ERROR] Unknown DB type \"$DBTYPE\", review your alfresco-bart.properties. Backup ABORTED!" >> $ALFBRT_LOG_FILE
		echo "$LOG_DATE_LOG - [ERROR] Unknown DB type \"$DBTYPE\", review your alfresco-bart.properties. Backup ABORTED!"	
		exit 1
		;; 
	esac 
	}

function contentStoreBackup {
	# Getting a variable to know all includes and excludes
	CONTENTSTORE_DIR_INCLUDES="--include $ALF_CONTENTSTORE"
	if [ "$ALF_CONTENSTORE_DELETED" != "" ]; then
		CS_DIR_INCLUDE_DELETED=" --include $ALF_CONTENSTORE_DELETED"
	fi
	if [ "$ALF_CACHED_CONTENTSTORE" != "" ]; then
		CS_DIR_INCLUDE_CACHED=" --include $ALF_CACHED_CONTENTSTORE"
	fi
	if [ "$ALF_CONTENTSTORE2" != "" ]; then
		CS_DIR_INCLUDE_CS2=" --include $ALF_CONTENTSTORE2"
	fi
	if [ "$ALF_CONTENTSTORE3" != "" ]; then
		CS_DIR_INCLUDE_CS3=" --include $ALF_CONTENTSTORE3"
	fi
	if [ "$ALF_CONTENTSTORE4" != "" ]; then
		CS_DIR_INCLUDE_CS4=" --include $ALF_CONTENTSTORE4"
	fi
	if [ "$ALF_CONTENTSTORE5" != "" ]; then
		CS_DIR_INCLUDE_CS5=" --include $ALF_CONTENTSTORE5"
	fi
	
	CONTENTSTORE_EXCLUDE_PARENT_DIR="$(dirname "$ALF_CONTENTSTORE")"
  	
  	echo "$LOG_DATE_LOG - $BART_LOG_TAG Backing up the Alfresco ContentStore to $BACKUPTYPE" >> $ALFBRT_LOG_FILE
  	echo "$LOG_DATE_LOG - $BART_LOG_TAG Starting backup - Alfresco ContentStore" >> $ALFBRT_LOG_FILE
  	echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN $PARAMS $CONTENTSTORE_DIR_INCLUDES $CS_DIR_INCLUDE_DELETED $CS_DIR_INCLUDE_CACHED $CS_DIR_INCLUDE_CS2 $CS_DIR_INCLUDE_CS3 $CS_DIR_INCLUDE_CS4 $CS_DIR_INCLUDE_CS5 --exclude $CONTENTSTORE_EXCLUDE_PARENT_DIR $CONTENTSTORE_EXCLUDE_PARENT_DIR $DEST/cs" >> $ALFBRT_LOG_FILE
 
 	# Content Store backup itself 
  	$DUPLICITYBIN $PARAMS $CONTENTSTORE_DIR_INCLUDES $CS_DIR_INCLUDE_DELETED $CS_DIR_INCLUDE_CACHED \
  	$CS_DIR_INCLUDE_CS2 $CS_DIR_INCLUDE_CS3 $CS_DIR_INCLUDE_CS4 $CS_DIR_INCLUDE_CS5 \
  	--exclude $CONTENTSTORE_EXCLUDE_PARENT_DIR $CONTENTSTORE_EXCLUDE_PARENT_DIR \
  	$DEST/cs >> $ALFBRT_LOG_FILE
  	echo "$LOG_DATE_LOG - $BART_LOG_TAG ContentStore backup done!" >> $ALFBRT_LOG_FILE
}

function filesBackup {
    # Getting a variable to know all includes and excludes
	FILES_DIR_INCLUDES="$ALF_INSTALLATION_DIR"
	
	if [ -d "$INDEXES_BACKUP_DIR" ]; then
		OPT_INDEXES_BACKUP_DIR=" --exclude $INDEXES_BACKUP_DIR"
	fi
	if [ -d "$INDEXES_DIR" ]; then
		OPT_INDEXES_DIR=" --exclude $INDEXES_DIR"
	fi
	if [ -d "$ALF_CONTENTSTORE" ]; then
		OPT_ALF_CONTENTSTORE=" --exclude $ALF_CONTENTSTORE"
	fi
	if [ -d "$ALF_CONTENSTORE_DELETED" ]; then
		OPT_ALF_CONTENSTORE_DELETED=" --exclude $ALF_CONTENSTORE_DELETED"
	fi
	if [ -d "$ALF_CACHED_CONTENTSTORE" ]; then
		OPT_CACHED_CONTENTSTORE=" --exclude $CACHED_CONTENTSTORE"
	fi
	if [ -d "$ALF_CONTENTSTORE2" ]; then
		OPT_ALF_CONTENTSTORE2=" --exclude $ALF_CONTENTSTORE2"
	fi
	if [ -d "$ALF_CONTENTSTORE3" ]; then
		OPT_ALF_CONTENTSTORE3=" --exclude $ALF_CONTENTSTORE3"
	fi
	if [ -d "$ALF_CONTENTSTORE4" ]; then
		OPT_ALF_CONTENTSTORE4=" --exclude $ALF_CONTENTSTORE4"
	fi
	if [ -d "$ALF_CONTENTSTORE5" ]; then
		OPT_ALF_CONTENTSTORE5=" --exclude $ALF_CONTENTSTORE5"
	fi
	if [ -d "$LOCAL_BACKUP_DB_DIR" ]; then
		OPT_LOCAL_BACKUP_DB_DIR=" --exclude $LOCAL_BACKUP_DB_DIR"
	fi
	
  	echo "$LOG_DATE_LOG - $BART_LOG_TAG Backing up the Alfresco files to $BACKUPTYPE" >> $ALFBRT_LOG_FILE
  	echo "$LOG_DATE_LOG - $BART_LOG_TAG Starting backup - Alfresco files" >> $ALFBRT_LOG_FILE
  	echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN $PARAMS $FILES_DIR_INCLUDES $OPT_INDEXES_BACKUP_DIR $OPT_INDEXES_DIR $OPT_ALF_CONTENTSTORE $OPT_ALF_CONTENSTORE_DELETED $OPT_CACHED_CONTENTSTORE $OPT_ALF_CONTENTSTORE2 $OPT_ALF_CONTENTSTORE3 $OPT_ALF_CONTENTSTORE4 $OPT_ALF_CONTENTSTORE5 $OPT_LOCAL_BACKUP_DB_DIR $OPT_LOCAL_DB_DIR $DEST/files" >> $ALFBRT_LOG_FILE
 
 	# files backup itself 
  	$DUPLICITYBIN $PARAMS $FILES_DIR_INCLUDES $OPT_INDEXES_BACKUP_DIR $OPT_INDEXES_DIR \
  	$OPT_ALF_CONTENTSTORE $OPT_ALF_CONTENSTORE_DELETED $OPT_CACHED_CONTENTSTORE \
  	$OPT_ALF_CONTENTSTORE2 $OPT_ALF_CONTENTSTORE3 $OPT_ALF_CONTENTSTORE4 $OPT_ALF_CONTENTSTORE5 \
  	$OPT_LOCAL_BACKUP_DB_DIR $OPT_LOCAL_DB_DIR $DEST/files >> $ALFBRT_LOG_FILE
  	echo "$LOG_DATE_LOG - $BART_LOG_TAG Files backup done!" >> $ALFBRT_LOG_FILE
}

function restoreWizard(){
    clear
    echo "################## Welcome to Alfresco BART restore wizard ###################"
    echo ""
    echo " This backup and recovery tool does not overrides nor modify your existing	"
    echo " data, then you must have a destination folder ready to complete the entire 	"
    echo " or partial restore process.											        "
    echo ""
    echo "##############################################################################"
    echo ""
    echo " Choose a restore option:"
    echo "	1- Full restore"
    echo " 	2- Partial restore"
    echo ""
    echo " Shortcuts available:"
    echo "	3- Restore alfresco-global.properties from a given date"
    echo "	4- Restore a single file of your Alfresco repository (NOT SUPPORTED YET)"
    echo "	5- Restore other configuration file (NOT SUPPORTED YET)"
    echo ""
    echo -n " Enter an option [1|2|3|4|5]: " 
    builtin read ASK1
    case $ASK1 in
    	1 ) 
    		RESTORECHOOSED=full
    		echo ""
    		echo " This wizard will help you to restore your Indexes, Data Base, Content Store and rest of files to a given directory."
    		echo ""
    		echo -n " Type a destination path with enough space available: "
    		builtin read RESTOREDIR
    		while [ ! -w $RESTOREDIR ]; do
    			echo " ERROR! Directory $RESTOREDIR does not exist or it does not have write permissions"
    			echo -n " please enter a valid path: "
    			builtin read RESTOREDIR
    		done
    		echo ""
    		echo -n " Do you want to see what backups collections are available to restore? [yes|no]: "
			read SHOWCOLANSWER
			shopt -s nocasematch
			case "$SHOWCOLANSWER" in
  				y|yes) 
  					collectionCommands collection all
					;;
  				n|no) 
    				;;
  				* ) echo "Incorrect value provided. Please enter yes or no." 
  				;; 
			esac
    		echo ""
    		echo " Specify a backup DATE (YYYY-MM-DD) to restore at or a number of DAYS+D since your valid backup. I.e.: if today is August 1st 2013 and want to restore a backup from July 26th 2013 then type \"2013-07-26\" or \"5D\" without quotes."
    		echo -n " Please type a date or number of days: " 
    		builtin read RESTOREDATE 
    		echo ""
    		echo " You want to restore a $RESTORECHOOSED backup from $BACKUPTYPE with date $RESTOREDATE to $RESTOREDIR"
    		echo -n " Is that correct? [yes|no]: "
    		read CONFIRMRESTORE
    		#duplicity restore --restore-time 
			read -p " To start restoring your selected backup press ENTER or CTRL+C to exit"
			echo ""
			echo " =========== Starting restore INDEXES from $DEST/$INDEXTYPE ==========="
			$DUPLICITYBIN restore --restore-time $RESTOREDATE $DEST/$INDEXTYPE $RESTOREDIR/$INDEXTYPE
			echo ""
			echo " =========== Starting restore DB from $DEST/$DBTYPE ==========="
			$DUPLICITYBIN restore --restore-time $RESTOREDATE $DEST/$DBTYPE $RESTOREDIR/$DBTYPE
			echo ""
			echo " =========== Starting restore CONTENT STORE from $DEST/cs ==========="
			$DUPLICITYBIN restore --restore-time $RESTOREDATE $DEST/cs $RESTOREDIR/cs
			echo ""
			echo " =========== Starting restore FILES from $DEST/files ==========="
			$DUPLICITYBIN restore --restore-time $RESTOREDATE $DEST/files $RESTOREDIR/files
			
			echo ""
			echo " Restore finished! Now you have to copy and replace your existing content with the content left in $RESTOREDIR, if you need a guideline about how to recovery your Alfresco installation from a backup please read the README file."
			echo ""
			exit 1
		;; 		
    	
  		2 ) 
  			RESTORECHOOSED=partial
    		echo ""
    		echo " This wizard will help you to restore one of your backup components: Indexes, Data Base, Content Store or rest of files to a given directory."
    		echo ""
    		echo -n " Type a component to restore [index|db|cs|files]: "
    		builtin read BACKUPGROUP
    		echo -n " Type a destination path with enough space available: "
    		builtin read RESTOREDIR
    		while [ ! -w $RESTOREDIR ]; do
    			echo " ERROR! Directory $RESTOREDIR does not exist or it does not have write permissions"
    			echo -n " please enter a valid path: "
    			builtin read RESTOREDIR
    		done
    		echo ""
    		echo -n " Do you want to see what backups collections are available for $BACKUPGROUP to restore? [yes|no]: "
			read SHOWCOLANSWER
			shopt -s nocasematch
			case "$SHOWCOLANSWER" in
  				y|yes) 
  					collectionCommands collection $BACKUPGROUP
					;;
  				n|no) 
    				;;
  				* ) echo "Incorrect value provided. Please enter yes or no." 
  				;; 
			esac
    		echo ""
    		echo " Specify a backup DATE (YYYY-MM-DD) to restore at or a number of DAYS+D since your valid backup. I.e.: if today is August 1st 2013 and want to restore a backup from July 26th 2013 then type \"2013-07-26\" or \"5D\" without quotes."
    		echo -n " Please type a date or number of days: " 
    		builtin read RESTOREDATE 
    		echo ""
    		echo " You want to restore a $RESTORECHOOSED backup of $BACKUPGROUP from $BACKUPTYPE with date $RESTOREDATE to $RESTOREDIR"
    		echo -n " Is that correct? [yes|no]: "
    		read CONFIRMRESTORE
    		#duplicity restore --restore-time 
			read -p " To start restoring your selected backup press ENTER or CTRL+C to exit"
			echo ""
			case $BACKUPGROUP in
			"index" )
				echo ""
				echo " =========== Starting restore INDEXES from $DEST/$INDEXTYPE ==========="
				$DUPLICITYBIN restore --restore-time $RESTOREDATE $DEST/$INDEXTYPE $RESTOREDIR/$INDEXTYPE
			;;
			"db" )
				echo ""
				echo " =========== Starting restore DB from $DEST/$DBTYPE ==========="
				$DUPLICITYBIN restore --restore-time $RESTOREDATE $DEST/$DBTYPE $RESTOREDIR/$DBTYPE
			;;
			"cs" )
				echo ""
				echo " =========== Starting restore CONTENT STORE from $DEST/cs ==========="
				$DUPLICITYBIN restore --restore-time $RESTOREDATE $DEST/cs $RESTOREDIR/cs
			;;
			"files" )
				echo ""
				echo " =========== Starting restore FILES from $DEST/files ==========="
				$DUPLICITYBIN restore --restore-time $RESTOREDATE $DEST/files $RESTOREDIR/files
    			;;
			* )
				echo "ERROR: Invalid parameter, there is no backup group with this name!"
			;;
			esac
			echo ""
			echo " Restore finished! Now you have to copy and replace your existing content with the content left in $RESTOREDIR, if you need a guideline about how to recovery your Alfresco installation from a backup please read the README file."
			echo ""
			exit 1
  			
		;;
		3 )
		echo "valid for Tomcat only *YET*"
		echo ""
    		echo " This option will restore an alfresco-global.properties backup. "
    		echo ""
    		echo -n " Type a destination path: "
    		builtin read RESTOREDIR
    		while [ ! -w $RESTOREDIR ]; do
    			echo " ERROR! Directory $RESTOREDIR does not exist or it does not have write permissions"
    			echo -n " please enter a valid path: "
    			builtin read RESTOREDIR
    		done
    		echo ""
    		echo -n " Do you want to see what backups collections are available for files to restore? [yes|no]: "
			read SHOWCOLANSWER
			shopt -s nocasematch
			case "$SHOWCOLANSWER" in
  				y|yes) 
  					collectionCommands collection files
					;;
  				n|no) 
    				;;
  				* ) echo "Incorrect value provided. Please enter yes or no." 
  				;; 
			esac
			
    		echo ""
    		echo " Specify a backup DATE (YYYY-MM-DD) to restore at or a number of DAYS+D since your valid backup. I.e.: if today is August 1st 2013 and want to restore a backup from July 26th 2013 then type \"2013-07-26\" or \"5D\" without quotes."
    		echo -n " Please type a date or number of days: " 
    		builtin read RESTOREDATE 
    		echo ""
    		echo " You want to restore a $RESTORECHOOSED backup of alfresco-global.properties from $BACKUPTYPE with date $RESTOREDATE to $RESTOREDIR"
    		echo -n " Is that correct? [yes|no]: "
    		read CONFIRMRESTORE
			read -p " To start restoring your selected backup press ENTER or CTRL+C to exit"
			echo ""
			$DUPLICITYBIN restore --restore-time $RESTOREDATE --file-to-restore tomcat/shared/classes/alfresco-global.properties $DEST/files $RESTOREDIR/alfresco-global.properties
		
		;;
		4 )
		
		;;
  		* ) 
  			restoreWizard
  		;;
		esac
	}
	
function verifyCommands (){
    	if [ -z $2 ]; then	
			echo "Please specify a valid backup group name to verify [index|db|cs|files|all]" 
		else
		case $2 in
			"index" )	
				echo "=========================== BACKUP VERIFICATION FOR INDEXES $INDEXTYPE ==========================="
   				$DUPLICITYBIN verify -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$INDEXTYPE $INDEXES_BACKUP_DIR  
				echo "DONE!"
			;;
			"db" )
				echo "=========================== BACKUP VERIFICATION FOR DB $DBTYPE ==========================="    
    			$DUPLICITYBIN verify -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$DBTYPE $LOCAL_BACKUP_DB_DIR
				echo "DONE!"
			;;
			"cs" )
				echo "=========================== BACKUP VERIFICATION FOR CONTENTSTORE ==========================="
    			$DUPLICITYBIN verify -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/cs $ALF_INSTALLATION_DIR
				echo "DONE!"
			;;
			"files" )
				echo "=========================== BACKUP VERIFICATION FOR FILES ==========================="
    			$DUPLICITYBIN verify -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/files $ALF_INSTALLATION_DIR
    			echo "DONE!"
    		;;
			"all" )
				echo "=========================== BACKUP VERIFICATION FOR INDEXES $INDEXTYPE ==========================="
				$DUPLICITYBIN verify -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$INDEXTYPE $INDEXES_BACKUP_DIR; \
				echo "=========================== BACKUP VERIFICATION FOR DB $DBTYPE ==========================="; \
	   			$DUPLICITYBIN verify -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$DBTYPE $LOCAL_BACKUP_DB_DIR; \
	   			echo "=========================== BACKUP VERIFICATION FOR CONTENTSTORE ==========================="; \
				$DUPLICITYBIN verify -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/cs $ALF_INSTALLATION_DIR; \
				echo "=========================== BACKUP VERIFICATION FOR FILES ==========================="; \
				$DUPLICITYBIN verify -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/files $ALF_INSTALLATION_DIR
			;;
			* )
				echo "WARNING: Invalid parameter, there is no backup group with this name!"
				listCommands
			;;
		esac 
		fi
    
	}

function listCommands(){
		if [ -z $2 ]; then	
			echo "Please specify a valid backup group name to list [index|db|cs|files|all]" 
		else
		case $2 in
			"index" )	
				$DUPLICITYBIN list-current-files -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$INDEXTYPE | less
			;;
			"db" )
				$DUPLICITYBIN list-current-files -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$DBTYPE | less
			;;
			"cs" )
				$DUPLICITYBIN list-current-files -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/cs | less
			;;
			"files" )
				$DUPLICITYBIN list-current-files -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/files | less
			;;
			"all" )
				$DUPLICITYBIN list-current-files -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$INDEXTYPE; \
				$DUPLICITYBIN list-current-files -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$DBTYPE; \
				$DUPLICITYBIN list-current-files -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/cs; \
				$DUPLICITYBIN list-current-files -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/files
			;;
			* )
				echo "WARNING: Invalid parameter, there is no backup group with this name!"
				listCommands
			;;
		esac 
		fi
	}

function collectionCommands () {
		if [ -z $2 ]; then	
			echo " Please specify a valid backup group name to access its collection [index|db|cs|files|all]" 
		else
		case $2 in
			"index" )	
				echo "======================= BACKUP COLLECTION FOR INDEXES $INDEXTYPE ======================"
    			$DUPLICITYBIN collection-status -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$INDEXTYPE
			;;
			"db" )
				echo "=========================== BACKUP COLLECTION FOR DB $DBTYPE =========================="
    			$DUPLICITYBIN collection-status -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$DBTYPE
			;;
			"cs" )
				echo "========================== BACKUP COLLECTION FOR CONTENTSTORE ========================="
    			$DUPLICITYBIN collection-status -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/cs
			;;
			"files" )
				echo "============================== BACKUP COLLECTION FOR FILES ============================"
    			$DUPLICITYBIN collection-status -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/files			
			;;
			"all" )
				echo "======================= BACKUP COLLECTION FOR INDEXES $INDEXTYPE ======================"
				$DUPLICITYBIN collection-status -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$INDEXTYPE; \
				echo "=========================== BACKUP COLLECTION FOR DB $DBTYPE =========================="; \
				$DUPLICITYBIN collection-status -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/$DBTYPE; \
				echo "========================== BACKUP COLLECTION FOR CONTENTSTORE ========================="; \
				$DUPLICITYBIN collection-status -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/cs; \
				echo "============================== BACKUP COLLECTION FOR FILES ============================"; \
				$DUPLICITYBIN collection-status -v${DUPLICITY_LOG_VERBOSITY} ${NOENCFLAG} --log-file=${ALFBRT_LOG_FILE} $DEST/files
			;;
			* )
				echo "WARNING: Invalid parameter, there is no backup group with this name!"
				collectionCommands
			;;
		esac 
		fi
    }
    
function maintenanceCommands () {
	# Function to apply backup policies
	echo "$LOG_DATE_LOG - $BART_LOG_TAG Running maintenance commands" >> $ALFBRT_LOG_FILE
	
	# Run maintenance if required/enabled
	if [ ${BACKUP_INDEX_ENABLED} == 'true' ]; then
		## INDEX backup collection maintenance
		echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/$INDEXTYPE" >> $ALFBRT_LOG_FILE
  		$DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/$INDEXTYPE >> $ALFBRT_LOG_FILE
  		echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-all-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/$INDEXTYPE" >> $ALFBRT_LOG_FILE 2>&1
  		$DUPLICITYBIN remove-all-inc-of-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/$INDEXTYPE >> $ALFBRT_LOG_FILE
	fi
	
	if [ ${BACKUP_DB_ENABLED} == 'true' ]; then
	case $DBTYPE in 
		"mysql" ) 
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/$DBTYPE" >> $ALFBRT_LOG_FILE
			$DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/$DBTYPE >> $ALFBRT_LOG_FILE
  			echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-all-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/$DBTYPE" >> $ALFBRT_LOG_FILE 2>&1
  			$DUPLICITYBIN remove-all-inc-of-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/$DBTYPE >> $ALFBRT_LOG_FILE
		;; 
		"postgresql" )
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/$DBTYPE" >> $ALFBRT_LOG_FILE
			$DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/$DBTYPE >> $ALFBRT_LOG_FILE
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-all-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/$DBTYPE" >> $ALFBRT_LOG_FILE 2>&1
			$DUPLICITYBIN remove-all-inc-of-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/$DBTYPE >> $ALFBRT_LOG_FILE		
		;; 		
		"oracle" )
			echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/$DBTYPE" >> $ALFBRT_LOG_FILE
  			$DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/$DBTYPE >> $ALFBRT_LOG_FILE
  			echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-all-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/$DBTYPE" >> $ALFBRT_LOG_FILE 2>&1
  			$DUPLICITYBIN remove-all-inc-of-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/$DBTYPE >> $ALFBRT_LOG_FILE
		;;	
	esac
	fi

	if [ ${BACKUP_CONTENTSTORE_ENABLED} == 'true' ]; then
		echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/cs" >> $ALFBRT_LOG_FILE
  		$DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/cs >> $ALFBRT_LOG_FILE 2>&1
  		echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-all-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/cs" >> $ALFBRT_LOG_FILE 2>&1
  		$DUPLICITYBIN remove-all-inc-of-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/cs >> $ALFBRT_LOG_FILE 2>&1
	fi
	if [ ${BACKUP_FILES_ENABLED} == 'true' ]; then
		echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/files" >> $ALFBRT_LOG_FILE
  		$DUPLICITYBIN remove-older-than $CLEAN_TIME -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force --extra-clean $DEST/files >> $ALFBRT_LOG_FILE 2>&1
  		echo "$LOG_DATE_LOG - $BART_LOG_TAG Running command - $DUPLICITYBIN remove-all-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/files" >> $ALFBRT_LOG_FILE 2>&1
  		$DUPLICITYBIN remove-all-inc-of-but-n-full $MAXFULL -v${DUPLICITY_LOG_VERBOSITY} --log-file=${ALFBRT_LOG_FILE} --force $DEST/files >> $ALFBRT_LOG_FILE 2>&1
	fi 
	echo "$LOG_DATE_LOG - $BART_LOG_TAG Maintenance commands DONE!" >> $ALFBRT_LOG_FILE
}

# Main options
case $1 in
	"backup" ) 
		echo "$LOG_DATE_LOG - $BART_LOG_TAG Starting backup" >> $ALFBRT_LOG_FILE
		echo "$LOG_DATE_LOG - $BART_LOG_TAG Set script varibles done" >> $ALFBRT_LOG_FILE
		# Run backup of indexes if enabled
		if [ ${BACKUP_INDEX_ENABLED} == 'true' ]; then
			indexBackup
		fi
		# Run backup of db if enabled
		if [ ${BACKUP_DB_ENABLED} == 'true' ]; then
			dbBackup
		fi
		# Run backup of contentStore if enabled
		if [ ${BACKUP_CONTENTSTORE_ENABLED} == 'true' ]; then
			contentStoreBackup
		fi
		# Run backup of files if enabled
		if [ ${BACKUP_FILES_ENABLED} == 'true' ]; then
			filesBackup
		fi 
		# Maintenance commands (cleanups and apply retention policies)
		if [ ${BACKUP_POLICIES_ENABLED} == 'true' ]; then
			maintenanceCommands
		fi 
		
	;;
	
	"restore" ) 
    	restoreWizard
    ;;
    
	"verify" ) 
		verifyCommands $1 $2
	;;
    
	"list" ) 
    	listCommands $1 $2
    ;;
    
	"collection" )
		collectionCommands $1 $2
    ;;

	"arrikitaun" )
		echo "Have a nice day!"
    ;;
    
	* ) 	
		usage
	;;
esac

# Unload al security variables
unset PASSPHRASE
unset AWS_ACCESS_KEY_ID
unset AWS_SECRET_ACCESS_KEY
unset DBPASS
unset FTP_PASSWORD
unset REC_MYPASS
unset REC_PGPASS
unset REC_ORAPASS